@@ -374,7 +374,7 @@ class YouTubeVideoPlayer(QThread):
 
     def playYouTubeVideo(self):
         playbackCommand = YouTubeVideoPlayer.playCommandDict.get(unicode(YouTubeVideoPlayer.mediaPlayer))
-        filename = "%s/%s.mp4" % (YouTubeVideoDownloader.downloadFolder, re.sub('[:/|\\\\]', "-", self.video.media.title.text).decode("utf-8"))
+        filename = "%s/%s.mp4" % (YouTubeVideoDownloader.downloadFolder, re.sub('[<>:"/|?*\\\\]', "_", self.video.media.title.text).decode("utf-8"))
         if os.path.exists(filename):
             os.system(playbackCommand % filename.encode("utf-8"))
         else:
